import sys

from find_libpython import main

if __name__ == "__main__":
    sys.exit(main())
